# This file was created automatically by SWIG.
import eventsc

from misc import *

from gdi import *

from fonts import *
class wxEventPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=eventsc.delete_wxEvent):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetEventObject(self, *_args, **_kwargs):
        val = apply(eventsc.wxEvent_GetEventObject,(self,) + _args, _kwargs)
        return val
    def GetEventType(self, *_args, **_kwargs):
        val = apply(eventsc.wxEvent_GetEventType,(self,) + _args, _kwargs)
        return val
    def GetId(self, *_args, **_kwargs):
        val = apply(eventsc.wxEvent_GetId,(self,) + _args, _kwargs)
        return val
    def GetSkipped(self, *_args, **_kwargs):
        val = apply(eventsc.wxEvent_GetSkipped,(self,) + _args, _kwargs)
        return val
    def GetTimestamp(self, *_args, **_kwargs):
        val = apply(eventsc.wxEvent_GetTimestamp,(self,) + _args, _kwargs)
        return val
    def SetEventObject(self, *_args, **_kwargs):
        val = apply(eventsc.wxEvent_SetEventObject,(self,) + _args, _kwargs)
        return val
    def SetEventType(self, *_args, **_kwargs):
        val = apply(eventsc.wxEvent_SetEventType,(self,) + _args, _kwargs)
        return val
    def SetId(self, *_args, **_kwargs):
        val = apply(eventsc.wxEvent_SetId,(self,) + _args, _kwargs)
        return val
    def SetTimestamp(self, *_args, **_kwargs):
        val = apply(eventsc.wxEvent_SetTimestamp,(self,) + _args, _kwargs)
        return val
    def Skip(self, *_args, **_kwargs):
        val = apply(eventsc.wxEvent_Skip,(self,) + _args, _kwargs)
        return val
    def Clone(self, *_args, **_kwargs):
        val = apply(eventsc.wxEvent_Clone,(self,) + _args, _kwargs)
        if val: val = wxEventPtr(val) 
        return val
    def __repr__(self):
        return "<C wxEvent instance at %s>" % (self.this,)
class wxEvent(wxEventPtr):
    def __init__(self,this):
        self.this = this




class wxSizeEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetSize(self, *_args, **_kwargs):
        val = apply(eventsc.wxSizeEvent_GetSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def __repr__(self):
        return "<C wxSizeEvent instance at %s>" % (self.this,)
class wxSizeEvent(wxSizeEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxSizeEvent,_args,_kwargs)
        self.thisown = 1




class wxCloseEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetLoggingOff(self, *_args, **_kwargs):
        val = apply(eventsc.wxCloseEvent_SetLoggingOff,(self,) + _args, _kwargs)
        return val
    def GetLoggingOff(self, *_args, **_kwargs):
        val = apply(eventsc.wxCloseEvent_GetLoggingOff,(self,) + _args, _kwargs)
        return val
    def Veto(self, *_args, **_kwargs):
        val = apply(eventsc.wxCloseEvent_Veto,(self,) + _args, _kwargs)
        return val
    def CanVeto(self, *_args, **_kwargs):
        val = apply(eventsc.wxCloseEvent_CanVeto,(self,) + _args, _kwargs)
        return val
    def GetVeto(self, *_args, **_kwargs):
        val = apply(eventsc.wxCloseEvent_GetVeto,(self,) + _args, _kwargs)
        return val
    def SetCanVeto(self, *_args, **_kwargs):
        val = apply(eventsc.wxCloseEvent_SetCanVeto,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxCloseEvent instance at %s>" % (self.this,)
class wxCloseEvent(wxCloseEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxCloseEvent,_args,_kwargs)
        self.thisown = 1




class wxCommandEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def IsChecked(self, *_args, **_kwargs):
        val = apply(eventsc.wxCommandEvent_IsChecked,(self,) + _args, _kwargs)
        return val
    def Checked(self, *_args, **_kwargs):
        val = apply(eventsc.wxCommandEvent_Checked,(self,) + _args, _kwargs)
        return val
    def GetExtraLong(self, *_args, **_kwargs):
        val = apply(eventsc.wxCommandEvent_GetExtraLong,(self,) + _args, _kwargs)
        return val
    def GetInt(self, *_args, **_kwargs):
        val = apply(eventsc.wxCommandEvent_GetInt,(self,) + _args, _kwargs)
        return val
    def GetSelection(self, *_args, **_kwargs):
        val = apply(eventsc.wxCommandEvent_GetSelection,(self,) + _args, _kwargs)
        return val
    def GetString(self, *_args, **_kwargs):
        val = apply(eventsc.wxCommandEvent_GetString,(self,) + _args, _kwargs)
        return val
    def IsSelection(self, *_args, **_kwargs):
        val = apply(eventsc.wxCommandEvent_IsSelection,(self,) + _args, _kwargs)
        return val
    def SetString(self, *_args, **_kwargs):
        val = apply(eventsc.wxCommandEvent_SetString,(self,) + _args, _kwargs)
        return val
    def SetExtraLong(self, *_args, **_kwargs):
        val = apply(eventsc.wxCommandEvent_SetExtraLong,(self,) + _args, _kwargs)
        return val
    def SetInt(self, *_args, **_kwargs):
        val = apply(eventsc.wxCommandEvent_SetInt,(self,) + _args, _kwargs)
        return val
    def GetClientData(self, *_args, **_kwargs):
        val = apply(eventsc.wxCommandEvent_GetClientData,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxCommandEvent instance at %s>" % (self.this,)
class wxCommandEvent(wxCommandEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxCommandEvent,_args,_kwargs)
        self.thisown = 1




class wxScrollEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetOrientation(self, *_args, **_kwargs):
        val = apply(eventsc.wxScrollEvent_GetOrientation,(self,) + _args, _kwargs)
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxScrollEvent_GetPosition,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxScrollEvent instance at %s>" % (self.this,)
class wxScrollEvent(wxScrollEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxScrollEvent,_args,_kwargs)
        self.thisown = 1




class wxScrollWinEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetOrientation(self, *_args, **_kwargs):
        val = apply(eventsc.wxScrollWinEvent_GetOrientation,(self,) + _args, _kwargs)
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxScrollWinEvent_GetPosition,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxScrollWinEvent instance at %s>" % (self.this,)
class wxScrollWinEvent(wxScrollWinEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxScrollWinEvent,_args,_kwargs)
        self.thisown = 1




class wxSpinEventPtr(wxScrollEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxSpinEvent instance at %s>" % (self.this,)
class wxSpinEvent(wxSpinEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxSpinEvent,_args,_kwargs)
        self.thisown = 1




class wxMouseEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def IsButton(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_IsButton,(self,) + _args, _kwargs)
        return val
    def ButtonDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_ButtonDown,(self,) + _args, _kwargs)
        return val
    def ButtonDClick(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_ButtonDClick,(self,) + _args, _kwargs)
        return val
    def ButtonUp(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_ButtonUp,(self,) + _args, _kwargs)
        return val
    def Button(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_Button,(self,) + _args, _kwargs)
        return val
    def ButtonIsDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_ButtonIsDown,(self,) + _args, _kwargs)
        return val
    def ControlDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_ControlDown,(self,) + _args, _kwargs)
        return val
    def MetaDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_MetaDown,(self,) + _args, _kwargs)
        return val
    def AltDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_AltDown,(self,) + _args, _kwargs)
        return val
    def ShiftDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_ShiftDown,(self,) + _args, _kwargs)
        return val
    def LeftDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_LeftDown,(self,) + _args, _kwargs)
        return val
    def MiddleDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_MiddleDown,(self,) + _args, _kwargs)
        return val
    def RightDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_RightDown,(self,) + _args, _kwargs)
        return val
    def LeftUp(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_LeftUp,(self,) + _args, _kwargs)
        return val
    def MiddleUp(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_MiddleUp,(self,) + _args, _kwargs)
        return val
    def RightUp(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_RightUp,(self,) + _args, _kwargs)
        return val
    def LeftDClick(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_LeftDClick,(self,) + _args, _kwargs)
        return val
    def MiddleDClick(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_MiddleDClick,(self,) + _args, _kwargs)
        return val
    def RightDClick(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_RightDClick,(self,) + _args, _kwargs)
        return val
    def LeftIsDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_LeftIsDown,(self,) + _args, _kwargs)
        return val
    def MiddleIsDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_MiddleIsDown,(self,) + _args, _kwargs)
        return val
    def RightIsDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_RightIsDown,(self,) + _args, _kwargs)
        return val
    def Dragging(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_Dragging,(self,) + _args, _kwargs)
        return val
    def Moving(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_Moving,(self,) + _args, _kwargs)
        return val
    def Entering(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_Entering,(self,) + _args, _kwargs)
        return val
    def Leaving(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_Leaving,(self,) + _args, _kwargs)
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetPositionTuple(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_GetPositionTuple,(self,) + _args, _kwargs)
        return val
    def GetLogicalPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_GetLogicalPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetX(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_GetX,(self,) + _args, _kwargs)
        return val
    def GetY(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_GetY,(self,) + _args, _kwargs)
        return val
    def GetWheelRotation(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_GetWheelRotation,(self,) + _args, _kwargs)
        return val
    def GetWheelDelta(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_GetWheelDelta,(self,) + _args, _kwargs)
        return val
    def GetLinesPerAction(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseEvent_GetLinesPerAction,(self,) + _args, _kwargs)
        return val
    def __setattr__(self,name,value):
        if name == "m_x" :
            eventsc.wxMouseEvent_m_x_set(self,value)
            return
        if name == "m_y" :
            eventsc.wxMouseEvent_m_y_set(self,value)
            return
        if name == "m_leftDown" :
            eventsc.wxMouseEvent_m_leftDown_set(self,value)
            return
        if name == "m_middleDown" :
            eventsc.wxMouseEvent_m_middleDown_set(self,value)
            return
        if name == "m_rightDown" :
            eventsc.wxMouseEvent_m_rightDown_set(self,value)
            return
        if name == "m_controlDown" :
            eventsc.wxMouseEvent_m_controlDown_set(self,value)
            return
        if name == "m_shiftDown" :
            eventsc.wxMouseEvent_m_shiftDown_set(self,value)
            return
        if name == "m_altDown" :
            eventsc.wxMouseEvent_m_altDown_set(self,value)
            return
        if name == "m_metaDown" :
            eventsc.wxMouseEvent_m_metaDown_set(self,value)
            return
        if name == "m_wheelRotation" :
            eventsc.wxMouseEvent_m_wheelRotation_set(self,value)
            return
        if name == "m_wheelDelta" :
            eventsc.wxMouseEvent_m_wheelDelta_set(self,value)
            return
        if name == "m_linesPerAction" :
            eventsc.wxMouseEvent_m_linesPerAction_set(self,value)
            return
        self.__dict__[name] = value
    def __getattr__(self,name):
        if name == "m_x" : 
            return eventsc.wxMouseEvent_m_x_get(self)
        if name == "m_y" : 
            return eventsc.wxMouseEvent_m_y_get(self)
        if name == "m_leftDown" : 
            return eventsc.wxMouseEvent_m_leftDown_get(self)
        if name == "m_middleDown" : 
            return eventsc.wxMouseEvent_m_middleDown_get(self)
        if name == "m_rightDown" : 
            return eventsc.wxMouseEvent_m_rightDown_get(self)
        if name == "m_controlDown" : 
            return eventsc.wxMouseEvent_m_controlDown_get(self)
        if name == "m_shiftDown" : 
            return eventsc.wxMouseEvent_m_shiftDown_get(self)
        if name == "m_altDown" : 
            return eventsc.wxMouseEvent_m_altDown_get(self)
        if name == "m_metaDown" : 
            return eventsc.wxMouseEvent_m_metaDown_get(self)
        if name == "m_wheelRotation" : 
            return eventsc.wxMouseEvent_m_wheelRotation_get(self)
        if name == "m_wheelDelta" : 
            return eventsc.wxMouseEvent_m_wheelDelta_get(self)
        if name == "m_linesPerAction" : 
            return eventsc.wxMouseEvent_m_linesPerAction_get(self)
        raise AttributeError,name
    def __repr__(self):
        return "<C wxMouseEvent instance at %s>" % (self.this,)
class wxMouseEvent(wxMouseEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxMouseEvent,_args,_kwargs)
        self.thisown = 1




class wxMouseCaptureChangedEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetCapturedWindow(self, *_args, **_kwargs):
        val = apply(eventsc.wxMouseCaptureChangedEvent_GetCapturedWindow,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxMouseCaptureChangedEvent instance at %s>" % (self.this,)
class wxMouseCaptureChangedEvent(wxMouseCaptureChangedEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxMouseCaptureChangedEvent,_args,_kwargs)
        self.thisown = 1




class wxSetCursorEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetX(self, *_args, **_kwargs):
        val = apply(eventsc.wxSetCursorEvent_GetX,(self,) + _args, _kwargs)
        return val
    def GetY(self, *_args, **_kwargs):
        val = apply(eventsc.wxSetCursorEvent_GetY,(self,) + _args, _kwargs)
        return val
    def SetCursor(self, *_args, **_kwargs):
        val = apply(eventsc.wxSetCursorEvent_SetCursor,(self,) + _args, _kwargs)
        return val
    def GetCursor(self, *_args, **_kwargs):
        val = apply(eventsc.wxSetCursorEvent_GetCursor,(self,) + _args, _kwargs)
        if val: val = wxCursorPtr(val) 
        return val
    def HasCursor(self, *_args, **_kwargs):
        val = apply(eventsc.wxSetCursorEvent_HasCursor,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSetCursorEvent instance at %s>" % (self.this,)
class wxSetCursorEvent(wxSetCursorEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxSetCursorEvent,_args,_kwargs)
        self.thisown = 1




class wxKeyEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def ControlDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_ControlDown,(self,) + _args, _kwargs)
        return val
    def MetaDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_MetaDown,(self,) + _args, _kwargs)
        return val
    def AltDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_AltDown,(self,) + _args, _kwargs)
        return val
    def ShiftDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_ShiftDown,(self,) + _args, _kwargs)
        return val
    def KeyCode(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_KeyCode,(self,) + _args, _kwargs)
        return val
    def GetKeyCode(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_GetKeyCode,(self,) + _args, _kwargs)
        return val
    def HasModifiers(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_HasModifiers,(self,) + _args, _kwargs)
        return val
    def GetRawKeyCode(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_GetRawKeyCode,(self,) + _args, _kwargs)
        return val
    def GetRawKeyFlags(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_GetRawKeyFlags,(self,) + _args, _kwargs)
        return val
    def GetX(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_GetX,(self,) + _args, _kwargs)
        return val
    def GetY(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_GetY,(self,) + _args, _kwargs)
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetPositionTuple(self, *_args, **_kwargs):
        val = apply(eventsc.wxKeyEvent_GetPositionTuple,(self,) + _args, _kwargs)
        return val
    def __setattr__(self,name,value):
        if name == "m_x" :
            eventsc.wxKeyEvent_m_x_set(self,value)
            return
        if name == "m_y" :
            eventsc.wxKeyEvent_m_y_set(self,value)
            return
        if name == "m_keyCode" :
            eventsc.wxKeyEvent_m_keyCode_set(self,value)
            return
        if name == "m_controlDown" :
            eventsc.wxKeyEvent_m_controlDown_set(self,value)
            return
        if name == "m_shiftDown" :
            eventsc.wxKeyEvent_m_shiftDown_set(self,value)
            return
        if name == "m_altDown" :
            eventsc.wxKeyEvent_m_altDown_set(self,value)
            return
        if name == "m_metaDown" :
            eventsc.wxKeyEvent_m_metaDown_set(self,value)
            return
        if name == "m_scanCode" :
            eventsc.wxKeyEvent_m_scanCode_set(self,value)
            return
        if name == "m_rawCode" :
            eventsc.wxKeyEvent_m_rawCode_set(self,value)
            return
        if name == "m_rawFlags" :
            eventsc.wxKeyEvent_m_rawFlags_set(self,value)
            return
        self.__dict__[name] = value
    def __getattr__(self,name):
        if name == "m_x" : 
            return eventsc.wxKeyEvent_m_x_get(self)
        if name == "m_y" : 
            return eventsc.wxKeyEvent_m_y_get(self)
        if name == "m_keyCode" : 
            return eventsc.wxKeyEvent_m_keyCode_get(self)
        if name == "m_controlDown" : 
            return eventsc.wxKeyEvent_m_controlDown_get(self)
        if name == "m_shiftDown" : 
            return eventsc.wxKeyEvent_m_shiftDown_get(self)
        if name == "m_altDown" : 
            return eventsc.wxKeyEvent_m_altDown_get(self)
        if name == "m_metaDown" : 
            return eventsc.wxKeyEvent_m_metaDown_get(self)
        if name == "m_scanCode" : 
            return eventsc.wxKeyEvent_m_scanCode_get(self)
        if name == "m_rawCode" : 
            return eventsc.wxKeyEvent_m_rawCode_get(self)
        if name == "m_rawFlags" : 
            return eventsc.wxKeyEvent_m_rawFlags_get(self)
        raise AttributeError,name
    def __repr__(self):
        return "<C wxKeyEvent instance at %s>" % (self.this,)
class wxKeyEvent(wxKeyEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxKeyEvent,_args,_kwargs)
        self.thisown = 1




class wxNavigationKeyEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetDirection(self, *_args, **_kwargs):
        val = apply(eventsc.wxNavigationKeyEvent_GetDirection,(self,) + _args, _kwargs)
        return val
    def SetDirection(self, *_args, **_kwargs):
        val = apply(eventsc.wxNavigationKeyEvent_SetDirection,(self,) + _args, _kwargs)
        return val
    def IsWindowChange(self, *_args, **_kwargs):
        val = apply(eventsc.wxNavigationKeyEvent_IsWindowChange,(self,) + _args, _kwargs)
        return val
    def SetWindowChange(self, *_args, **_kwargs):
        val = apply(eventsc.wxNavigationKeyEvent_SetWindowChange,(self,) + _args, _kwargs)
        return val
    def GetCurrentFocus(self, *_args, **_kwargs):
        val = apply(eventsc.wxNavigationKeyEvent_GetCurrentFocus,(self,) + _args, _kwargs)
        return val
    def SetCurrentFocus(self, *_args, **_kwargs):
        val = apply(eventsc.wxNavigationKeyEvent_SetCurrentFocus,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxNavigationKeyEvent instance at %s>" % (self.this,)
class wxNavigationKeyEvent(wxNavigationKeyEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxNavigationKeyEvent,_args,_kwargs)
        self.thisown = 1




class wxMoveEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxMoveEvent_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def __repr__(self):
        return "<C wxMoveEvent instance at %s>" % (self.this,)
class wxMoveEvent(wxMoveEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxMoveEvent,_args,_kwargs)
        self.thisown = 1




class wxPaintEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxPaintEvent instance at %s>" % (self.this,)
class wxPaintEvent(wxPaintEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxPaintEvent,_args,_kwargs)
        self.thisown = 1




class wxEraseEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetDC(self, *_args, **_kwargs):
        val = apply(eventsc.wxEraseEvent_GetDC,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxEraseEvent instance at %s>" % (self.this,)
class wxEraseEvent(wxEraseEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxEraseEvent,_args,_kwargs)
        self.thisown = 1




class wxFocusEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxFocusEvent instance at %s>" % (self.this,)
class wxFocusEvent(wxFocusEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxFocusEvent,_args,_kwargs)
        self.thisown = 1




class wxChildFocusEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetWindow(self, *_args, **_kwargs):
        val = apply(eventsc.wxChildFocusEvent_GetWindow,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxChildFocusEvent instance at %s>" % (self.this,)
class wxChildFocusEvent(wxChildFocusEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxChildFocusEvent,_args,_kwargs)
        self.thisown = 1




class wxActivateEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetActive(self, *_args, **_kwargs):
        val = apply(eventsc.wxActivateEvent_GetActive,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxActivateEvent instance at %s>" % (self.this,)
class wxActivateEvent(wxActivateEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxActivateEvent,_args,_kwargs)
        self.thisown = 1




class wxInitDialogEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxInitDialogEvent instance at %s>" % (self.this,)
class wxInitDialogEvent(wxInitDialogEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxInitDialogEvent,_args,_kwargs)
        self.thisown = 1




class wxMenuEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetMenuId(self, *_args, **_kwargs):
        val = apply(eventsc.wxMenuEvent_GetMenuId,(self,) + _args, _kwargs)
        return val
    def IsPopup(self, *_args, **_kwargs):
        val = apply(eventsc.wxMenuEvent_IsPopup,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxMenuEvent instance at %s>" % (self.this,)
class wxMenuEvent(wxMenuEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxMenuEvent,_args,_kwargs)
        self.thisown = 1




class wxShowEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetShow(self, *_args, **_kwargs):
        val = apply(eventsc.wxShowEvent_SetShow,(self,) + _args, _kwargs)
        return val
    def GetShow(self, *_args, **_kwargs):
        val = apply(eventsc.wxShowEvent_GetShow,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxShowEvent instance at %s>" % (self.this,)
class wxShowEvent(wxShowEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxShowEvent,_args,_kwargs)
        self.thisown = 1




class wxIconizeEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Iconized(self, *_args, **_kwargs):
        val = apply(eventsc.wxIconizeEvent_Iconized,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxIconizeEvent instance at %s>" % (self.this,)
class wxIconizeEvent(wxIconizeEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxIconizeEvent,_args,_kwargs)
        self.thisown = 1




class wxMaximizeEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxMaximizeEvent instance at %s>" % (self.this,)
class wxMaximizeEvent(wxMaximizeEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxMaximizeEvent,_args,_kwargs)
        self.thisown = 1




class wxJoystickEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetZPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_GetZPosition,(self,) + _args, _kwargs)
        return val
    def GetButtonState(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_GetButtonState,(self,) + _args, _kwargs)
        return val
    def GetButtonChange(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_GetButtonChange,(self,) + _args, _kwargs)
        return val
    def GetJoystick(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_GetJoystick,(self,) + _args, _kwargs)
        return val
    def SetJoystick(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_SetJoystick,(self,) + _args, _kwargs)
        return val
    def SetButtonState(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_SetButtonState,(self,) + _args, _kwargs)
        return val
    def SetButtonChange(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_SetButtonChange,(self,) + _args, _kwargs)
        return val
    def SetPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_SetPosition,(self,) + _args, _kwargs)
        return val
    def SetZPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_SetZPosition,(self,) + _args, _kwargs)
        return val
    def IsButton(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_IsButton,(self,) + _args, _kwargs)
        return val
    def IsMove(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_IsMove,(self,) + _args, _kwargs)
        return val
    def IsZMove(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_IsZMove,(self,) + _args, _kwargs)
        return val
    def ButtonDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_ButtonDown,(self,) + _args, _kwargs)
        return val
    def ButtonUp(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_ButtonUp,(self,) + _args, _kwargs)
        return val
    def ButtonIsDown(self, *_args, **_kwargs):
        val = apply(eventsc.wxJoystickEvent_ButtonIsDown,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxJoystickEvent instance at %s>" % (self.this,)
class wxJoystickEvent(wxJoystickEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxJoystickEvent,_args,_kwargs)
        self.thisown = 1




class wxDropFilesEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxDropFilesEvent_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetNumberOfFiles(self, *_args, **_kwargs):
        val = apply(eventsc.wxDropFilesEvent_GetNumberOfFiles,(self,) + _args, _kwargs)
        return val
    def GetFiles(self, *_args, **_kwargs):
        val = apply(eventsc.wxDropFilesEvent_GetFiles,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxDropFilesEvent instance at %s>" % (self.this,)
class wxDropFilesEvent(wxDropFilesEventPtr):
    def __init__(self,this):
        self.this = this




class wxIdleEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def RequestMore(self, *_args, **_kwargs):
        val = apply(eventsc.wxIdleEvent_RequestMore,(self,) + _args, _kwargs)
        return val
    def MoreRequested(self, *_args, **_kwargs):
        val = apply(eventsc.wxIdleEvent_MoreRequested,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxIdleEvent instance at %s>" % (self.this,)
class wxIdleEvent(wxIdleEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxIdleEvent,_args,_kwargs)
        self.thisown = 1




class wxUpdateUIEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetChecked(self, *_args, **_kwargs):
        val = apply(eventsc.wxUpdateUIEvent_GetChecked,(self,) + _args, _kwargs)
        return val
    def GetEnabled(self, *_args, **_kwargs):
        val = apply(eventsc.wxUpdateUIEvent_GetEnabled,(self,) + _args, _kwargs)
        return val
    def GetText(self, *_args, **_kwargs):
        val = apply(eventsc.wxUpdateUIEvent_GetText,(self,) + _args, _kwargs)
        return val
    def GetSetText(self, *_args, **_kwargs):
        val = apply(eventsc.wxUpdateUIEvent_GetSetText,(self,) + _args, _kwargs)
        return val
    def GetSetChecked(self, *_args, **_kwargs):
        val = apply(eventsc.wxUpdateUIEvent_GetSetChecked,(self,) + _args, _kwargs)
        return val
    def GetSetEnabled(self, *_args, **_kwargs):
        val = apply(eventsc.wxUpdateUIEvent_GetSetEnabled,(self,) + _args, _kwargs)
        return val
    def Check(self, *_args, **_kwargs):
        val = apply(eventsc.wxUpdateUIEvent_Check,(self,) + _args, _kwargs)
        return val
    def Enable(self, *_args, **_kwargs):
        val = apply(eventsc.wxUpdateUIEvent_Enable,(self,) + _args, _kwargs)
        return val
    def SetText(self, *_args, **_kwargs):
        val = apply(eventsc.wxUpdateUIEvent_SetText,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxUpdateUIEvent instance at %s>" % (self.this,)
class wxUpdateUIEvent(wxUpdateUIEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxUpdateUIEvent,_args,_kwargs)
        self.thisown = 1




class wxSysColourChangedEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxSysColourChangedEvent instance at %s>" % (self.this,)
class wxSysColourChangedEvent(wxSysColourChangedEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxSysColourChangedEvent,_args,_kwargs)
        self.thisown = 1




class wxNotifyEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def IsAllowed(self, *_args, **_kwargs):
        val = apply(eventsc.wxNotifyEvent_IsAllowed,(self,) + _args, _kwargs)
        return val
    def Allow(self, *_args, **_kwargs):
        val = apply(eventsc.wxNotifyEvent_Allow,(self,) + _args, _kwargs)
        return val
    def Veto(self, *_args, **_kwargs):
        val = apply(eventsc.wxNotifyEvent_Veto,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxNotifyEvent instance at %s>" % (self.this,)
class wxNotifyEvent(wxNotifyEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxNotifyEvent,_args,_kwargs)
        self.thisown = 1




class wxDisplayChangedEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxDisplayChangedEvent instance at %s>" % (self.this,)
class wxDisplayChangedEvent(wxDisplayChangedEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxDisplayChangedEvent,_args,_kwargs)
        self.thisown = 1




class wxPaletteChangedEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetChangedWindow(self, *_args, **_kwargs):
        val = apply(eventsc.wxPaletteChangedEvent_SetChangedWindow,(self,) + _args, _kwargs)
        return val
    def GetChangedWindow(self, *_args, **_kwargs):
        val = apply(eventsc.wxPaletteChangedEvent_GetChangedWindow,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPaletteChangedEvent instance at %s>" % (self.this,)
class wxPaletteChangedEvent(wxPaletteChangedEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxPaletteChangedEvent,_args,_kwargs)
        self.thisown = 1




class wxQueryNewPaletteEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetPaletteRealized(self, *_args, **_kwargs):
        val = apply(eventsc.wxQueryNewPaletteEvent_SetPaletteRealized,(self,) + _args, _kwargs)
        return val
    def GetPaletteRealized(self, *_args, **_kwargs):
        val = apply(eventsc.wxQueryNewPaletteEvent_GetPaletteRealized,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxQueryNewPaletteEvent instance at %s>" % (self.this,)
class wxQueryNewPaletteEvent(wxQueryNewPaletteEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxQueryNewPaletteEvent,_args,_kwargs)
        self.thisown = 1




class wxWindowCreateEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetWindow(self, *_args, **_kwargs):
        val = apply(eventsc.wxWindowCreateEvent_GetWindow,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxWindowCreateEvent instance at %s>" % (self.this,)
class wxWindowCreateEvent(wxWindowCreateEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxWindowCreateEvent,_args,_kwargs)
        self.thisown = 1




class wxWindowDestroyEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetWindow(self, *_args, **_kwargs):
        val = apply(eventsc.wxWindowDestroyEvent_GetWindow,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxWindowDestroyEvent instance at %s>" % (self.this,)
class wxWindowDestroyEvent(wxWindowDestroyEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxWindowDestroyEvent,_args,_kwargs)
        self.thisown = 1




class wxContextMenuEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxContextMenuEvent_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) 
        return val
    def SetPosition(self, *_args, **_kwargs):
        val = apply(eventsc.wxContextMenuEvent_SetPosition,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxContextMenuEvent instance at %s>" % (self.this,)
class wxContextMenuEvent(wxContextMenuEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxContextMenuEvent,_args,_kwargs)
        self.thisown = 1




class wxTimerEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetInterval(self, *_args, **_kwargs):
        val = apply(eventsc.wxTimerEvent_GetInterval,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxTimerEvent instance at %s>" % (self.this,)
class wxTimerEvent(wxTimerEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxTimerEvent,_args,_kwargs)
        self.thisown = 1




class wxTextUrlEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetMouseEvent(self, *_args, **_kwargs):
        val = apply(eventsc.wxTextUrlEvent_GetMouseEvent,(self,) + _args, _kwargs)
        return val
    def GetURLStart(self, *_args, **_kwargs):
        val = apply(eventsc.wxTextUrlEvent_GetURLStart,(self,) + _args, _kwargs)
        return val
    def GetURLEnd(self, *_args, **_kwargs):
        val = apply(eventsc.wxTextUrlEvent_GetURLEnd,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxTextUrlEvent instance at %s>" % (self.this,)
class wxTextUrlEvent(wxTextUrlEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxTextUrlEvent,_args,_kwargs)
        self.thisown = 1




class wxPyEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=eventsc.delete_wxPyEvent):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def SetSelf(self, *_args, **_kwargs):
        val = apply(eventsc.wxPyEvent_SetSelf,(self,) + _args, _kwargs)
        return val
    def GetSelf(self, *_args, **_kwargs):
        val = apply(eventsc.wxPyEvent_GetSelf,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyEvent instance at %s>" % (self.this,)
class wxPyEvent(wxPyEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxPyEvent,_args,_kwargs)
        self.thisown = 1
        self.SetSelf(self)




class wxPyCommandEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=eventsc.delete_wxPyCommandEvent):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def SetSelf(self, *_args, **_kwargs):
        val = apply(eventsc.wxPyCommandEvent_SetSelf,(self,) + _args, _kwargs)
        return val
    def GetSelf(self, *_args, **_kwargs):
        val = apply(eventsc.wxPyCommandEvent_GetSelf,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyCommandEvent instance at %s>" % (self.this,)
class wxPyCommandEvent(wxPyCommandEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(eventsc.new_wxPyCommandEvent,_args,_kwargs)
        self.thisown = 1
        self.SetSelf(self)






#-------------- FUNCTION WRAPPERS ------------------

wxNewEventType = eventsc.wxNewEventType



#-------------- VARIABLE WRAPPERS ------------------




# This file was created automatically by SWIG.
import sizersc

from misc import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from controls import *

from events import *
import wx
class wxSizerItemPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def DeleteWindows(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_DeleteWindows,(self,) + _args, _kwargs)
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetSize(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_GetSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def CalcMin(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_CalcMin,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def SetDimension(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_SetDimension,(self,) + _args, _kwargs)
        return val
    def SetRatioWH(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_SetRatioWH,(self,) + _args, _kwargs)
        return val
    def SetRatioSize(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_SetRatioSize,(self,) + _args, _kwargs)
        return val
    def SetRatio(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_SetRatio,(self,) + _args, _kwargs)
        return val
    def GetRatio(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_GetRatio,(self,) + _args, _kwargs)
        return val
    def IsWindow(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_IsWindow,(self,) + _args, _kwargs)
        return val
    def IsSizer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_IsSizer,(self,) + _args, _kwargs)
        return val
    def IsSpacer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_IsSpacer,(self,) + _args, _kwargs)
        return val
    def IsShown(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_IsShown,(self,) + _args, _kwargs)
        return val
    def GetWindow(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_GetWindow,(self,) + _args, _kwargs)
        return val
    def SetWindow(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_SetWindow,(self,) + _args, _kwargs)
        return val
    def GetSizer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_GetSizer,(self,) + _args, _kwargs)
        return val
    def SetSizer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_SetSizer,(self,) + _args, _kwargs)
        return val
    def GetOption(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_GetOption,(self,) + _args, _kwargs)
        return val
    def GetFlag(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_GetFlag,(self,) + _args, _kwargs)
        return val
    def GetBorder(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_GetBorder,(self,) + _args, _kwargs)
        return val
    def SetInitSize(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_SetInitSize,(self,) + _args, _kwargs)
        return val
    def SetOption(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_SetOption,(self,) + _args, _kwargs)
        return val
    def SetFlag(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_SetFlag,(self,) + _args, _kwargs)
        return val
    def SetBorder(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_SetBorder,(self,) + _args, _kwargs)
        return val
    def Show(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_Show,(self,) + _args, _kwargs)
        return val
    def GetUserData(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizerItem_GetUserData,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSizerItem instance at %s>" % (self.this,)
class wxSizerItem(wxSizerItemPtr):
    def __init__(self,this):
        self.this = this




class wxSizerPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setOORInfo(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer__setOORInfo,(self,) + _args, _kwargs)
        return val
    def Destroy(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_Destroy,(self,) + _args, _kwargs)
        return val
    def AddWindow(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_AddWindow,(self,) + _args, _kwargs)
        return val
    def AddSizer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_AddSizer,(self,) + _args, _kwargs)
        return val
    def AddSpacer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_AddSpacer,(self,) + _args, _kwargs)
        return val
    def InsertWindow(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_InsertWindow,(self,) + _args, _kwargs)
        return val
    def InsertSizer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_InsertSizer,(self,) + _args, _kwargs)
        return val
    def InsertSpacer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_InsertSpacer,(self,) + _args, _kwargs)
        return val
    def PrependWindow(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_PrependWindow,(self,) + _args, _kwargs)
        return val
    def PrependSizer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_PrependSizer,(self,) + _args, _kwargs)
        return val
    def PrependSpacer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_PrependSpacer,(self,) + _args, _kwargs)
        return val
    def RemoveWindow(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_RemoveWindow,(self,) + _args, _kwargs)
        return val
    def RemoveSizer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_RemoveSizer,(self,) + _args, _kwargs)
        return val
    def RemovePos(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_RemovePos,(self,) + _args, _kwargs)
        return val
    def SetDimension(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_SetDimension,(self,) + _args, _kwargs)
        return val
    def SetMinSize(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_SetMinSize,(self,) + _args, _kwargs)
        return val
    def SetItemMinSizeWindow(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_SetItemMinSizeWindow,(self,) + _args, _kwargs)
        return val
    def SetItemMinSizeSizer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_SetItemMinSizeSizer,(self,) + _args, _kwargs)
        return val
    def SetItemMinSizePos(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_SetItemMinSizePos,(self,) + _args, _kwargs)
        return val
    def GetSize(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_GetSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetMinSize(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_GetMinSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def Layout(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_Layout,(self,) + _args, _kwargs)
        return val
    def Fit(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_Fit,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def FitInside(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_FitInside,(self,) + _args, _kwargs)
        return val
    def SetSizeHints(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_SetSizeHints,(self,) + _args, _kwargs)
        return val
    def SetVirtualSizeHints(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_SetVirtualSizeHints,(self,) + _args, _kwargs)
        return val
    def Clear(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_Clear,(self,) + _args, _kwargs)
        return val
    def DeleteWindows(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_DeleteWindows,(self,) + _args, _kwargs)
        return val
    def GetChildren(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_GetChildren,(self,) + _args, _kwargs)
        return val
    def ShowWindow(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_ShowWindow,(self,) + _args, _kwargs)
        return val
    def HideWindow(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_HideWindow,(self,) + _args, _kwargs)
        return val
    def ShowSizer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_ShowSizer,(self,) + _args, _kwargs)
        return val
    def HideSizer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_HideSizer,(self,) + _args, _kwargs)
        return val
    def IsShownWindow(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_IsShownWindow,(self,) + _args, _kwargs)
        return val
    def IsShownSizer(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_IsShownSizer,(self,) + _args, _kwargs)
        return val
    def ShowItems(self, *_args, **_kwargs):
        val = apply(sizersc.wxSizer_ShowItems,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSizer instance at %s>" % (self.this,)
    
    def Add(self, *args, **kw):
        if type(args[0]) == type(1):
            apply(self.AddSpacer, args, kw)
        elif isinstance(args[0], wxSizerPtr):
            apply(self.AddSizer, args, kw)
        elif isinstance(args[0], wxWindowPtr):
            apply(self.AddWindow, args, kw)
        else:
            raise TypeError, 'Expected int, wxSizer or wxWindow parameter'

    def Insert(self, *args, **kw):
        if type(args[1]) == type(1):
            apply(self.InsertSpacer, args, kw)
        elif isinstance(args[1], wxSizerPtr):
            apply(self.InsertSizer, args, kw)
        elif isinstance(args[1], wxWindowPtr):
            apply(self.InsertWindow, args, kw)
        else:
            raise TypeError, 'Expected int, wxSizer or wxWindow parameter'

    def Prepend(self, *args, **kw):
        if type(args[0]) == type(1):
            apply(self.PrependSpacer, args, kw)
        elif isinstance(args[0], wxSizerPtr):
            apply(self.PrependSizer, args, kw)
        elif isinstance(args[0], wxWindowPtr):
            apply(self.PrependWindow, args, kw)
        else:
            raise TypeError, 'Expected int, wxSizer or wxWindow parameter'

    def Remove(self, *args, **kw):
        if type(args[0]) == type(1):
            return apply(self.RemovePos, args, kw)
        elif isinstance(args[0], wxSizerPtr):
            return apply(self.RemoveSizer, args, kw)
        elif isinstance(args[0], wxWindowPtr):
            return apply(self.RemoveWindow, args, kw)
        else:
            raise TypeError, 'Expected int, wxSizer or wxWindow parameter'

    def AddMany(self, widgets):
        for childinfo in widgets:
            if type(childinfo) != type(()):
                childinfo = (childinfo, )
            apply(self.Add, childinfo)

    
    def SetItemMinSize(self, *args):
        if type(args[0]) == type(1):
            apply(self.SetItemMinSizePos, args)
        elif isinstance(args[0], wxSizerPtr):
            apply(self.SetItemMinSizeSizer, args)
        elif isinstance(args[0], wxWindowPtr):
            apply(self.SetItemMinSizeWindow, args)
        else:
            raise TypeError, 'Expected int, wxSizer or wxWindow parameter'
     
    
    def GetSizeTuple(self):
        return self.GetSize().asTuple()
    def GetPositionTuple(self):
        return self.GetPosition().asTuple()
    def GetMinSizeTuple(self):
        return self.GetMinSize().asTuple()
    
    
    def Show(self, *args):
        if isinstance(args[0], wxSizerPtr):
            apply(self.ShowSizer, args)
        elif isinstance(args[0], wxWindowPtr):
            apply(self.ShowWindow, args)
        else:
            raise TypeError, 'Expected wxSizer or wxWindow parameter'

    def Hide(self, *args):
        if isinstance(args[0], wxSizerPtr):
            apply(self.HideSizer, args)
        elif isinstance(args[0], wxWindowPtr):
            apply(self.HideWindow, args)
        else:
            raise TypeError, 'Expected wxSizer or wxWindow parameter'

    def IsShown(self, *args):
        if isinstance(args[0], wxSizerPtr):
            return apply(self.IsShownSizer, args)
        elif isinstance(args[0], wxWindowPtr):
            return apply(self.IsShownWindow, args)
        else:
            raise TypeError, 'Expected wxSizer or wxWindow parameter'

class wxSizer(wxSizerPtr):
    def __init__(self,this):
        self.this = this




class wxPySizerPtr(wxSizerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(sizersc.wxPySizer__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPySizer instance at %s>" % (self.this,)
class wxPySizer(wxPySizerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(sizersc.new_wxPySizer,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPySizer)
        self._setOORInfo(self)




class wxBoxSizerPtr(wxSizerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetOrientation(self, *_args, **_kwargs):
        val = apply(sizersc.wxBoxSizer_GetOrientation,(self,) + _args, _kwargs)
        return val
    def SetOrientation(self, *_args, **_kwargs):
        val = apply(sizersc.wxBoxSizer_SetOrientation,(self,) + _args, _kwargs)
        return val
    def RecalcSizes(self, *_args, **_kwargs):
        val = apply(sizersc.wxBoxSizer_RecalcSizes,(self,) + _args, _kwargs)
        return val
    def CalcMin(self, *_args, **_kwargs):
        val = apply(sizersc.wxBoxSizer_CalcMin,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def __repr__(self):
        return "<C wxBoxSizer instance at %s>" % (self.this,)
class wxBoxSizer(wxBoxSizerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(sizersc.new_wxBoxSizer,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxStaticBoxSizerPtr(wxBoxSizerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetStaticBox(self, *_args, **_kwargs):
        val = apply(sizersc.wxStaticBoxSizer_GetStaticBox,(self,) + _args, _kwargs)
        return val
    def RecalcSizes(self, *_args, **_kwargs):
        val = apply(sizersc.wxStaticBoxSizer_RecalcSizes,(self,) + _args, _kwargs)
        return val
    def CalcMin(self, *_args, **_kwargs):
        val = apply(sizersc.wxStaticBoxSizer_CalcMin,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def __repr__(self):
        return "<C wxStaticBoxSizer instance at %s>" % (self.this,)
class wxStaticBoxSizer(wxStaticBoxSizerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(sizersc.new_wxStaticBoxSizer,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxNotebookSizerPtr(wxSizerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def RecalcSizes(self, *_args, **_kwargs):
        val = apply(sizersc.wxNotebookSizer_RecalcSizes,(self,) + _args, _kwargs)
        return val
    def CalcMin(self, *_args, **_kwargs):
        val = apply(sizersc.wxNotebookSizer_CalcMin,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetNotebook(self, *_args, **_kwargs):
        val = apply(sizersc.wxNotebookSizer_GetNotebook,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxNotebookSizer instance at %s>" % (self.this,)
class wxNotebookSizer(wxNotebookSizerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(sizersc.new_wxNotebookSizer,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridSizerPtr(wxSizerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def RecalcSizes(self, *_args, **_kwargs):
        val = apply(sizersc.wxGridSizer_RecalcSizes,(self,) + _args, _kwargs)
        return val
    def CalcMin(self, *_args, **_kwargs):
        val = apply(sizersc.wxGridSizer_CalcMin,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def SetCols(self, *_args, **_kwargs):
        val = apply(sizersc.wxGridSizer_SetCols,(self,) + _args, _kwargs)
        return val
    def SetRows(self, *_args, **_kwargs):
        val = apply(sizersc.wxGridSizer_SetRows,(self,) + _args, _kwargs)
        return val
    def SetVGap(self, *_args, **_kwargs):
        val = apply(sizersc.wxGridSizer_SetVGap,(self,) + _args, _kwargs)
        return val
    def SetHGap(self, *_args, **_kwargs):
        val = apply(sizersc.wxGridSizer_SetHGap,(self,) + _args, _kwargs)
        return val
    def GetCols(self, *_args, **_kwargs):
        val = apply(sizersc.wxGridSizer_GetCols,(self,) + _args, _kwargs)
        return val
    def GetRows(self, *_args, **_kwargs):
        val = apply(sizersc.wxGridSizer_GetRows,(self,) + _args, _kwargs)
        return val
    def GetVGap(self, *_args, **_kwargs):
        val = apply(sizersc.wxGridSizer_GetVGap,(self,) + _args, _kwargs)
        return val
    def GetHGap(self, *_args, **_kwargs):
        val = apply(sizersc.wxGridSizer_GetHGap,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridSizer instance at %s>" % (self.this,)
class wxGridSizer(wxGridSizerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(sizersc.new_wxGridSizer,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxFlexGridSizerPtr(wxGridSizerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def RecalcSizes(self, *_args, **_kwargs):
        val = apply(sizersc.wxFlexGridSizer_RecalcSizes,(self,) + _args, _kwargs)
        return val
    def CalcMin(self, *_args, **_kwargs):
        val = apply(sizersc.wxFlexGridSizer_CalcMin,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def AddGrowableRow(self, *_args, **_kwargs):
        val = apply(sizersc.wxFlexGridSizer_AddGrowableRow,(self,) + _args, _kwargs)
        return val
    def RemoveGrowableRow(self, *_args, **_kwargs):
        val = apply(sizersc.wxFlexGridSizer_RemoveGrowableRow,(self,) + _args, _kwargs)
        return val
    def AddGrowableCol(self, *_args, **_kwargs):
        val = apply(sizersc.wxFlexGridSizer_AddGrowableCol,(self,) + _args, _kwargs)
        return val
    def RemoveGrowableCol(self, *_args, **_kwargs):
        val = apply(sizersc.wxFlexGridSizer_RemoveGrowableCol,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFlexGridSizer instance at %s>" % (self.this,)
class wxFlexGridSizer(wxFlexGridSizerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(sizersc.new_wxFlexGridSizer,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)






#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------




#----------------------------------------------------------------------------
# Name:        wxPython.lib.mixins.grid
# Purpose:     Helpful mix-in classes for wxGrid
#
# Author:      Robin Dunn
#
# Created:     5-June-2001
# RCS-ID:      $Id: grid.py,v 1.1 2001/06/25 23:46:28 RD Exp $
# Copyright:   (c) 2001 by Total Control Software
# Licence:     wxWindows license
#----------------------------------------------------------------------------

from wxPython import wx, grid

#----------------------------------------------------------------------------


class wxGridAutoEditMixin:
    """A mix-in class that automatically enables the grid edit control when
    a cell is selected.

    If your class hooks EVT_GRID_SELECT_CELL be sure to call event.Skip so
    this handler will be called too.
    """

    def __init__(self):
        self.__enableEdit = 0
        wx.EVT_IDLE(self, self.__OnIdle)
        grid.EVT_GRID_SELECT_CELL(self, self.__OnSelectCell)


    def __OnIdle(self, evt):
        if self.__enableEdit:
            if self.CanEnableCellControl():
                self.EnableCellEditControl()
            self.__enableEdit = 0
        evt.Skip()


    def __OnSelectCell(self, evt):
        self.__enableEdit = 1
        evt.Skip()




"""Provides global signal dispatching services."""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: dispatcher.py,v 1.1.2.1 2003/03/05 20:24:18 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]

import exceptions
import types
import weakref

try:
    True
except NameError:
    True = 1==1
    False = 1==0


class DispatcherError(exceptions.Exception):
    def __init__(self, args=None):
        self.args = args


class Parameter:
    """Used to represent default parameter values."""
    def __repr__(self):
        return self.__class__.__name__

class Any(Parameter): pass
Any = Any()

class Anonymous(Parameter): pass
Anonymous = Anonymous()


connections = {}
senders = {}
_boundMethods = weakref.WeakKeyDictionary()


def connect(receiver, signal=Any, sender=Any, weak=True):
    """Connect receiver to sender for signal.
    
    If sender is Any, receiver will receive signal from any sender.
    If signal is Any, receiver will receive any signal from sender.
    If sender is None, receiver will receive signal from Anonymous.
    If signal is Any and sender is None, receiver will receive any 
        signal from Anonymous.
    If signal is Any and sender is Any, receiver will receive any 
        signal from any sender.
    If weak is true, weak references will be used."""
    if signal is None:
        raise DispatcherError, 'signal cannot be None'
    if weak:
        receiver = safeRef(receiver)
    senderkey = id(sender)
    signals = {}
    if connections.has_key(senderkey):
        signals = connections[senderkey]
    else:
        connections[senderkey] = signals
        # Keep track of senders for cleanup.
        if sender not in (None, Any):
            def remove(object, senderkey=senderkey):
                _removeSender(senderkey=senderkey)
            # Skip objects that can not be weakly referenced, which means
            # they won't be automatically cleaned up, but that's too bad.
            try:
                weakSender = weakref.ref(sender, remove)
                senders[senderkey] = weakSender
            except:
                pass
    receivers = []
    if signals.has_key(signal):
        receivers = signals[signal]
    else:
        signals[signal] = receivers
    try:
        receivers.remove(receiver)
    except ValueError:
        pass
    receivers.append(receiver)

def disconnect(receiver, signal=Any, sender=Any, weak=True):
    """Disconnect receiver from sender for signal.
    
    Disconnecting is not required. The use of disconnect is the same as for
    connect, only in reverse. Think of it as undoing a previous connection."""
    if signal is None:
        raise DispatcherError, 'signal cannot be None'
    if weak:
        receiver = safeRef(receiver)
    senderkey = id(sender)
    try:
        receivers = connections[senderkey][signal]
    except KeyError:
        raise DispatcherError, \
              'No receivers for signal %r from sender %s' % (signal, sender)
    try:
        receivers.remove(receiver)
    except ValueError:
        raise DispatcherError, \
              'No connection to receiver %s for signal %r from sender %s' % \
              (receiver, signal, sender)
    _cleanupConnections(senderkey, signal)

def send(signal, sender=Anonymous, **kwds):
    """Send signal from sender to all connected receivers.
    
    Return a list of tuple pairs [(receiver, response), ... ].
    If sender is not specified, signal is sent anonymously."""
    senderkey = id(sender)
    anykey = id(Any)
    # Get receivers that receive *this* signal from *this* sender.
    receivers = []
    try:
        receivers.extend(connections[senderkey][signal])
    except KeyError:
        pass
    # Add receivers that receive *any* signal from *this* sender.
    anyreceivers = []
    try:
        anyreceivers = connections[senderkey][Any]
    except KeyError:
        pass
    for receiver in anyreceivers:
        if receivers.count(receiver) == 0:
            receivers.append(receiver)
    # Add receivers that receive *this* signal from *any* sender.
    anyreceivers = []
    try:
        anyreceivers = connections[anykey][signal]
    except KeyError:
        pass
    for receiver in anyreceivers:
        if receivers.count(receiver) == 0:
            receivers.append(receiver)
    # Add receivers that receive *any* signal from *any* sender.
    anyreceivers = []
    try:
        anyreceivers = connections[anykey][Any]
    except KeyError:
        pass
    for receiver in anyreceivers:
        if receivers.count(receiver) == 0:
            receivers.append(receiver)
    # Call each receiver with whatever arguments it can accept.
    # Return a list of tuple pairs [(receiver, response), ... ].
    responses = []
    for receiver in receivers:
        if type(receiver) is weakref.ReferenceType \
        or isinstance(receiver, BoundMethodWeakref):
            # Dereference the weak reference.
            receiver = receiver()
            if receiver is None:
                # This receiver is dead, so skip it.
                continue
        response = _call(receiver, signal=signal, sender=sender, **kwds)
        responses += [(receiver, response)]
    return responses

def _call(receiver, **kwds):
    """Call receiver with only arguments it can accept."""
##    if type(receiver) is types.InstanceType:
    if hasattr(receiver, '__call__') and \
       (hasattr(receiver.__call__, 'im_func') or hasattr(receiver.__call__, 'im_code')):
        # receiver is a class instance; assume it is callable.
        # Reassign receiver to the actual method that will be called.
        receiver = receiver.__call__
    if hasattr(receiver, 'im_func'):
        # receiver is a method. Drop the first argument, usually 'self'.
        fc = receiver.im_func.func_code
        acceptable = fc.co_varnames[1:fc.co_argcount]
    elif hasattr(receiver, 'func_code'):
        # receiver is a function.
        fc = receiver.func_code
        acceptable = fc.co_varnames[0:fc.co_argcount]
    else:
        raise DispatcherError, 'Unknown receiver %s of type %s' % (receiver, type(receiver))
    if not (fc.co_flags & 8):
        # fc does not have a **kwds type parameter, therefore 
        # remove unacceptable arguments.
        for arg in kwds.keys():
            if arg not in acceptable:
                del kwds[arg]
    return receiver(**kwds)


def safeRef(object):
    """Return a *safe* weak reference to a callable object."""
    if hasattr(object, 'im_self'):
        if object.im_self is not None:
            # Turn a bound method into a BoundMethodWeakref instance.
            # Keep track of these instances for lookup by disconnect().
            selfkey = object.im_self
            funckey = object.im_func
            if not _boundMethods.has_key(selfkey):
                _boundMethods[selfkey] = weakref.WeakKeyDictionary()
            if not _boundMethods[selfkey].has_key(funckey):
                _boundMethods[selfkey][funckey] = \
                BoundMethodWeakref(boundMethod=object)
            return _boundMethods[selfkey][funckey]
    return weakref.ref(object, _removeReceiver)


class BoundMethodWeakref:
    """BoundMethodWeakref class."""

    def __init__(self, boundMethod):
        """Return a weak-reference-like instance for a bound method."""
        self.isDead = 0
        def remove(object, self=self):
            """Set self.isDead to true when method or instance is destroyed."""
            self.isDead = 1
            _removeReceiver(receiver=self)
        self.weakSelf = weakref.ref(boundMethod.im_self, remove)
        self.weakFunc = weakref.ref(boundMethod.im_func, remove)

    def __repr__(self):
        """Return the closest representation."""
        return '<bound method weakref for %s.%s>' % (self.weakSelf, self.weakFunc)

    def __call__(self):
        """Return a strong reference to the bound method."""
        if self.isDead:
            return None
        else:
            object = self.weakSelf()
            method = self.weakFunc().__name__
            try:  # wxPython hack to handle wxDead objects.
                return getattr(object, method)
            except AttributeError:
##                 _removeReceiver(receiver=self)
                return None


def _removeReceiver(receiver):
    """Remove receiver from connections."""
    for senderkey in connections.keys():
        for signal in connections[senderkey].keys():
            receivers = connections[senderkey][signal]
            try:
                receivers.remove(receiver)
            except:
                pass
            _cleanupConnections(senderkey, signal)
            
def _cleanupConnections(senderkey, signal):
    """Delete any empty signals for senderkey. Delete senderkey if empty."""
    receivers = connections[senderkey][signal]
    if not receivers:
        # No more connected receivers. Therefore, remove the signal.
        signals = connections[senderkey]
        del signals[signal]
        if not signals:
            # No more signal connections. Therefore, remove the sender.
            _removeSender(senderkey)
            
def _removeSender(senderkey):
    """Remove senderkey from connections."""
    del connections[senderkey]
    # Senderkey will only be in senders dictionary if sender 
    # could be weakly referenced.
    try:
        del senders[senderkey]
    except:
        pass



from wxPython.wx import wxLayoutConstraints,\
                wxTop, wxLeft, wxBottom, wxRight, \
                wxHeight, wxWidth, wxCentreX, wxCentreY
import re

class Layoutf(wxLayoutConstraints):
    """
The class Layoutf(wxLayoutConstraints) presents a simplification
of the wxLayoutConstraints syntax. The name Layoutf is choosen
because of the similarity with C's printf function.

Quick Example:

    lc = Layoutf('t=t#1;l=r10#2;r!100;h%h50#1', (self, self.panel))

is equivalent to

    lc = wxLayoutContraints()
    lc.top.SameAs(self, wxTop)
    lc.left.SameAs(self.panel, wxRight, 10)
    lc.right.Absolute(100)
    lc.height.PercentOf(self, wxHeight, 50)

Usage:

    You can give a constraint string to the Layoutf constructor,
or use the 'pack' method. The following are equivalent:

    lc = Layoutf('t=t#1;l=r#2;r!100;h%h50#1', (self, self.panel))

and

    lc = Layoutf()
    lc.pack('t=t#1;l=r#2;r!100;h%h50#1', (self, self.panel))

    Besides 'pack' there's also 'debug_pack' which does not set
constraints, but prints traditional wxLayoutConstraint calls to
stdout.

    The calls to the Layoutf constructor and pack methods have
the following argument list:

    (constraint_string, objects_tuple)

Constraint String syntax:

    Constraint directives are separated by semi-colons. You
generally (always?) need four directives to completely describe a
subwindow's location.

    A single directive has either of the following forms:

    1. <own attribute><compare operation>[numerical argument]
    for example r!100 -> lc.right.Absolute(100) )
    and w* -> lc.width.AsIs()

    2. <own attribute><compare operation>[numerical argument]
       #<compare object nr.>
    for example t_10#2 (lc.top.Below(<second obj>, 10)

    3. <own attribute><compare operation><compare attribute>
       [numerical argument]#<compare object nr.>
    for example w%h50#2 ( lc.width.PercentOf(<second obj>,
    wxHeight, 50) and t=b#1 ( lc.top.SameAs(<first obj>,
    wxBottom) )

    Which one you need is defined by the <compare operation>
type. The following take type 1 (no object to compare with):

    '!': 'Absolute', '?': 'Unconstrained', '*': 'AsIs'

These take type 2 (need to be compared with another object)

    '<': 'LeftOf', '>': 'RightOf', '^': 'Above', '_': 'Below'

These take type 3 (need to be compared to another object
attribute)

    '=': 'SameAs', '%': 'PercentOf'

For all types, the <own attribute> letter can be any of

    't': 'top', 'l': 'left', 'b': 'bottom',
    'r': 'right', 'h': 'height', 'w': 'width',
    'x': 'centreX', 'y': 'centreY'

If the operation takes an (optional) numerical argument, place it
in [numerical argument].  For type 3 directives, the <compare
attribute> letter can be any of

    't': 'wxTop', 'l': 'wxLeft', 'b': 'wxBottom'
    'r': 'wxRight', 'h': 'wxHeight', 'w': 'wxWidth',
    'x': 'wxCentreX', 'y': 'wxCentreY'

Note that these are the same letters as used for <own attribute>,
so you'll only need to remember one set. Finally, the object
whose attribute is refered to, is specified by #<compare object
nr>, where <compare object nr> is the 1-based (stupid, I know,
but I've gotten used to it) index of the object in the
objects_tuple argument.

Bugs:

Not entirely happy about the logic in the order of arguments
after the <compare operation> character.

Not all wxLayoutConstraint methods are included in the
syntax. However, the type 3 directives are generally the most
used. Further excuse: wxWindows layout constraints are at the
time of this writing not documented.

"""

    attr_d = { 't': 'top', 'l': 'left', 'b': 'bottom',
             'r': 'right', 'h': 'height', 'w': 'width',
             'x': 'centreX', 'y': 'centreY' }
    op_d = { '=': 'SameAs', '%': 'PercentOf', '<': 'LeftOf',
              '>': 'RightOf', '^': 'Above', '_': 'Below',
               '!': 'Absolute', '?': 'Unconstrained', '*': 'AsIs' }
    cmp_d = { 't': 'wxTop', 'l': 'wxLeft', 'b': 'wxBottom',
             'r': 'wxRight', 'h': 'wxHeight', 'w': 'wxWidth',
             'x': 'wxCentreX', 'y': 'wxCentreY' }

    rexp1 = re.compile('^\s*([tlrbhwxy])\s*([!\?\*])\s*(\d*)\s*$')
    rexp2 = re.compile('^\s*([tlrbhwxy])\s*([=%<>^_])\s*([tlrbhwxy]?)\s*(\d*)\s*#(\d+)\s*$')

    def __init__(self,pstr=None,winlist=None):
        wxLayoutConstraints.__init__(self)
        if pstr:
            self.pack(pstr,winlist)

    def pack(self, pstr, winlist):
        pstr = pstr.lower()
        for item in pstr.split(';'):
            m = self.rexp1.match(item)
            if m:
                g = list(m.groups())
                attr = getattr(self, self.attr_d[g[0]])
                func = getattr(attr, self.op_d[g[1]])
                if g[1] == '!':
                    func(int(g[2]))
                else:
                    func()
                continue
            m = self.rexp2.match(item)
            if not m: raise ValueError
            g = list(m.groups())
            attr = getattr(self, self.attr_d[g[0]])
            func = getattr(attr, self.op_d[g[1]])
            if g[3]: g[3] = int(g[3])
            else: g[3] = None;
            g[4] = int(g[4]) - 1
            if g[1] in '<>^_':
                if g[3]: func(winlist[g[4]], g[3])
                else: func(winlist[g[4]])
            else:
                cmp = eval(self.cmp_d[g[2]])
                if g[3]: func(winlist[g[4]], cmp, g[3])
                else: func(winlist[g[4]], cmp)

    def debug_pack(self, pstr, winlist):
        pstr = pstr.lower()
        for item in pstr.split(';'):
            m = self.rexp1.match(item)
            if m:
                g = list(m.groups())
                attr = getattr(self, self.attr_d[g[0]])
                func = getattr(attr, self.op_d[g[1]])
                if g[1] == '!':
                    print "%s.%s.%s(%s)" % \
                     ('self',self.attr_d[g[0]],self.op_d[g[1]],g[2])
                else:
                    print "%s.%s.%s()" % \
                     ('self',self.attr_d[g[0]],self.op_d[g[1]])
                continue
            m = self.rexp2.match(item)
            if not m: raise ValueError
            g = list(m.groups())
            if g[3]: g[3] = int(g[3])
            else: g[3] = 0;
            g[4] = int(g[4]) - 1
            if g[1] in '<>^_':
                if g[3]: print "%s.%s.%s(%s,%d)" % \
                 ('self',self.attr_d[g[0]],self.op_d[g[1]],winlist[g[4]],
                  g[3])
                else: print "%s.%s.%s(%s)" % \
                 ('self',self.attr_d[g[0]],self.op_d[g[1]],winlist[g[4]])
            else:
                if g[3]: print "%s.%s.%s(%s,%s,%d)" % \
                 ('self',self.attr_d[g[0]],self.op_d[g[1]],winlist[g[4]],
                  self.cmp_d[g[2]],g[3])
                else: print "%s.%s.%s(%s,%s)" % \
                 ('self',self.attr_d[g[0]],self.op_d[g[1]],winlist[g[4]],
                  self.cmp_d[g[2]])

if __name__=='__main__':
    from wxPython.wx import *

    class TestLayoutf(wxFrame):
        def __init__(self, parent):
            wxFrame.__init__(self, parent, -1, 'Test Layout Constraints',
                             wxPyDefaultPosition, wxSize(500, 300))
            EVT_CLOSE(self, self.OnCloseWindow)

            self.SetAutoLayout(True)
            EVT_BUTTON(self, 100, self.OnButton)
            EVT_BUTTON(self, 101, self.OnAbout)

            self.panelA = wxWindow(self, -1, wxPyDefaultPosition, wxPyDefaultSize, wxSIMPLE_BORDER)
            self.panelA.SetBackgroundColour(wxBLUE)
            self.panelA.SetConstraints(Layoutf('t=t10#1;l=l10#1;b=b10#1;r%r50#1',(self,)))

            self.panelB = wxWindow(self, -1, wxPyDefaultPosition, wxPyDefaultSize, wxSIMPLE_BORDER)
            self.panelB.SetBackgroundColour(wxRED)
            self.panelB.SetConstraints(Layoutf('t=t10#1;r=r10#1;b%b30#1;l>10#2', (self,self.panelA)))

            self.panelC = wxWindow(self, -1, wxPyDefaultPosition, wxPyDefaultSize, wxSIMPLE_BORDER)
            self.panelC.SetBackgroundColour(wxWHITE)
            self.panelC.SetConstraints(Layoutf('t_10#3;r=r10#1;b=b10#1;l>10#2', (self,self.panelA,self.panelB)))

            b = wxButton(self.panelA, 101, ' About: ')
            b.SetConstraints(Layoutf('X=X#1;Y=Y#1;h*;w%w50#1', (self.panelA,)))

            b = wxButton(self.panelB, 100, ' Panel B ')
            b.SetConstraints(Layoutf('t=t2#1;r=r4#1;h*;w*', (self.panelB,)))

            self.panelD = wxWindow(self.panelC, -1, wxPyDefaultPosition, wxPyDefaultSize, wxSIMPLE_BORDER)
            self.panelD.SetBackgroundColour(wxGREEN)
            self.panelD.SetConstraints(Layoutf('b%h50#1;r%w50#1;h=h#2;w=w#2', (self.panelC, b)))

            b = wxButton(self.panelC, 100, ' Panel C ')
            b.SetConstraints(Layoutf('t_#1;l>#1;h*;w*', (self.panelD,)))

            wxStaticText(self.panelD, -1, "Panel D", wxPoint(4, 4)).SetBackgroundColour(wxGREEN)

        def OnButton(self, event):
            self.Close(True)

        def OnAbout(self, event):
            try:
                from dialogs import wxScrolledMessageDialog
                msg = wxScrolledMessageDialog(self, Layoutf.__doc__, "about")
                msg.ShowModal()
            except:
                print msg

        def OnCloseWindow(self, event):
            self.Destroy()

    class TestApp(wxApp):
        def OnInit(self):
            frame = TestLayoutf(NULL)
            frame.Show(1)
            self.SetTopWindow(frame)
            return 1

    app = TestApp(0)
    app.MainLoop()








"""wxFancyText -- methods for rendering XML specified text

This module has four main methods:

def getExtent(str, dc=None, enclose=1):
def renderToBitmap(str, background=None, enclose=1)
def renderToDC(str, dc, x, y, enclose=1)

In all cases, 'str' is an XML string. The tags in the string can
currently specify the font, subscripts, superscripts, and the angle
sign. The allowable properties of font are size, family, style, weght,
encoding, and color. See the example on the bottom for a better idea
of how this works.

Note that start and end tags for the string are provided if enclose is
True, so for instance, renderToBitmap("X<sub>1</sub>") will work.

"""
# Copyright 2001 Timothy Hochberg
# Use as you see fit. No warantees, I cannot be held responsible, etc.



# TODO:  Make a wxFancyTextCtrl class that derives from wxControl.
#        Add support for line breaks
#        etc.
#        - Robin



from wxPython.wx import *
import xml.parsers.expat, copy

_families = {"default" : wxDEFAULT, "decorative" : wxDECORATIVE, "roman" : wxROMAN,
                "swiss" : wxSWISS, "modern" : wxMODERN}
_styles = {"normal" : wxNORMAL, "slant" : wxSLANT, "italic" : wxITALIC}
_weights = {"normal" : wxNORMAL, "light" : wxLIGHT, "bold" : wxBOLD}

# The next three classes: Renderer, SizeRenderer and DCRenderer are
# what you will need to override to extend the XML language. All of
# the font stuff as well as the subscript and superscript stuff are in
# Renderer.

class Renderer:

    defaultSize = wxNORMAL_FONT.GetPointSize()
    defaultFamily = wxDEFAULT
    defaultStyle = wxNORMAL
    defaultWeight = wxNORMAL
    defaultEncoding = wxFont_GetDefaultEncoding()
    defaultColor = "black"

    def __init__(self, dc=None):
        if dc == None:
            dc = wxMemoryDC()
        self.dc = dc
        self.offsets = [0]
        self.fonts = [{}]

    def startElement(self, name, attrs):
        method = "start_" + name
        if not hasattr(self, method):
            raise ValueError("XML tag '%s' not supported" % name)
        getattr(self, method)(attrs)

    def endElement(self, name):
        method = "end_" + name
        if not hasattr(self, method):
            raise ValueError("XML tag '%s' not supported" % name)
        getattr(self, method)()

    def start_wxFancyString(self, attrs):
        pass

    def end_wxFancyString(self):
        pass

    def start_font(self, attrs):
        for key, value in attrs.items():
            if key == "size":
                value = int(value)
            elif key == "family":
                value = _families[value]
            elif key == "style":
                value = _styles[value]
            elif key == "weight":
                value = _weights[value]
            elif key == "encoding":
                pass
            elif key == "color":
                pass
            else:
                raise ValueError("unknown font attribute '%s'" % key)
            attrs[key] = value
        font = copy.copy(self.fonts[-1])
        font.update(attrs)
        self.fonts.append(font)

    def end_font(self):
        self.fonts.pop()

    def start_sub(self, attrs):
        if attrs.keys():
            raise ValueError("<sub> does not take attributes")
        font = self.getCurrentFont()
        self.offsets.append(self.offsets[-1] + self.dc.GetFullTextExtent("M", font)[1]*0.5)
        self.start_font({"size" : font.GetPointSize() * 0.8})

    def end_sub(self):
        self.fonts.pop()
        self.offsets.pop()

    def start_sup(self, attrs):
        if attrs.keys():
            raise ValueError("<sup> does not take attributes")
        font = self.getCurrentFont()
        self.offsets.append(self.offsets[-1] - self.dc.GetFullTextExtent("M", font)[1]*0.3)
        self.start_font({"size" : font.GetPointSize() * 0.8})

    def end_sup(self):
        self.fonts.pop()
        self.offsets.pop()

    def getCurrentFont(self):
        font = self.fonts[-1]
        return wxFont(font.get("size", self.defaultSize),
                             font.get("family", self.defaultFamily),
                             font.get("style", self.defaultStyle),
                             font.get("weight", self.defaultWeight),
                             encoding = font.get("encoding", self.defaultEncoding))

    def getCurrentColor(self):
        font = self.fonts[-1]
        return wxNamedColour(font.get("color", self.defaultColor))


class SizeRenderer(Renderer):

    def __init__(self, dc=None):
        Renderer.__init__(self, dc)
        self.width = self.height = 0
        self.minY = self.maxY = 0

    def characterData(self, data):
        self.dc.SetFont(self.getCurrentFont())
        width, height = self.dc.GetTextExtent(data)
        self.width = self.width +  width
        self.minY = min(self.minY, self.offsets[-1])
        self.maxY = max(self.maxY, self.offsets[-1] + height)
        self.height = self.maxY - self.minY

    def start_angle(self, attrs):
        self.characterData("M")

    def end_angle(self):
        pass

class DCRenderer(Renderer):

    def __init__(self, dc=None, x=0, y=0):
        Renderer.__init__(self, dc)
        self.x = x
        self.y = y

    def characterData(self, data):
        self.dc.SetFont(self.getCurrentFont())
        self.dc.SetTextForeground(self.getCurrentColor())
        width, height = self.dc.GetTextExtent(data)
        self.dc.DrawText(data, self.x, self.y + self.offsets[-1])
        self.x = self.x + width

    def start_angle(self, attrs):
        self.dc.SetFont(self.getCurrentFont())
        self.dc.SetPen(wxPen(self.getCurrentColor(), 1))
        width, height, descent, leading = self.dc.GetFullTextExtent("M")
        y = self.y + self.offsets[-1] + height - descent
        self.dc.DrawLine(self.x, y, self.x+width, y)
        self.dc.DrawLine(self.x, y, self.x+width, y-width)
        self.x = self.x + width

    def end_angle(self):
        pass

# This is a rendering function that is primarily used internally,
# although it could be used externally if one had overridden the
# Renderer classes.

def renderToRenderer(str, renderer, enclose=1):
    if enclose:
        str = '<?xml version="1.0"?><wxFancyString>%s</wxFancyString>' % str
    p = xml.parsers.expat.ParserCreate()
    p.returns_unicode = 0
    p.StartElementHandler = renderer.startElement
    p.EndElementHandler = renderer.endElement
    p.CharacterDataHandler = renderer.characterData
    p.Parse(str, 1)


def getExtent(str, dc=None, enclose=1):
    "Return the extent of str"
    renderer = SizeRenderer(dc)
    renderToRenderer(str, renderer, enclose)
    return wxSize(renderer.width, renderer.height)

# This should probably only be used internally....

def getFullExtent(str, dc=None, enclose=1):
    renderer = SizeRenderer(dc)
    renderToRenderer(str, renderer, enclose)
    return renderer.width, renderer.height, -renderer.minY

def renderToBitmap(str, background=None, enclose=1):
    "Return str rendered on a minumum size bitmap"
    dc = wxMemoryDC()
    width, height, dy = getFullExtent(str, dc)
    bmp = wxEmptyBitmap(width, height)
    dc.SelectObject(bmp)
    if background is not None:
        dc.SetBackground(background)
    dc.Clear()
    renderer = DCRenderer(dc, y=dy)
    dc.BeginDrawing()
    renderToRenderer(str, renderer, enclose)
    dc.EndDrawing()
    dc.SelectObject(wxNullBitmap)
    return bmp

def renderToDC(str, dc, x, y, enclose=1):
    "Render str onto a wxDC at (x,y)"
    width, height, dy = getFullExtent(str, dc)
    renderer = DCRenderer(dc, x, y+dy)
    renderToRenderer(str, renderer, enclose)


if __name__ == "__main__":
    str = ('<font style="italic" family="swiss" color="red" weight="bold" >some  |<sup>23</sup> <angle/>text<sub>with <angle/> subscript</sub> </font> some other text'
            '<font family="swiss" color="green" size="40">big green text</font>')
    ID_EXIT  = 102
    class myApp(wxApp):
        def OnInit(self):
            return 1
    app = myApp()
    frame = wxFrame(NULL, -1, "wxFancyText demo", wxDefaultPosition)
    frame.SetClientSize(getExtent(str))
    bmp = renderToBitmap(str, wxCYAN_BRUSH)
    sb = wxStaticBitmap(frame, -1, bmp)
    EVT_MENU(frame, ID_EXIT, frame.Destroy)
    frame.Show(1)
    app.MainLoop()



"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: EventFunctions.py,v 1.1.2.1 2003/03/11 19:37:13 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


def EVT_ACTIVATE(win, func):
    """"""
    pass

def EVT_ACTIVATE_APP(win, func):
    """"""
    pass

def EVT_BUTTON(win, id, func):
    """"""
    pass

def EVT_CALCULATE_LAYOUT():
    """"""
    pass

def EVT_CHAR(win, func):
    """"""
    pass

def EVT_CHAR_HOOK(win, func):
    """"""
    pass

def EVT_CHECKBOX(win, id, func):
    """"""
    pass

def EVT_CHECKLISTBOX(win, id, func):
    """"""
    pass

def EVT_CHILD_FOCUS(win, func):
    """"""
    pass

def EVT_CHOICE(win, id, func):
    """"""
    pass

def EVT_CLOSE(win, func):
    """"""
    pass

def EVT_COMBOBOX(win, id, func):
    """"""
    pass

def EVT_COMMAND(win, id, cmd, func):
    """"""
    pass

def EVT_COMMAND_ENTER(win, id, func):
    """"""
    pass

def EVT_COMMAND_FIND():
    """"""
    pass

def EVT_COMMAND_FIND_CLOSE():
    """"""
    pass

def EVT_COMMAND_FIND_NEXT():
    """"""
    pass

def EVT_COMMAND_FIND_REPLACE():
    """"""
    pass

def EVT_COMMAND_FIND_REPLACE_ALL():
    """"""
    pass

def EVT_COMMAND_KILL_FOCUS(win, id, func):
    """"""
    pass

def EVT_COMMAND_LEFT_CLICK(win, id, func):
    """"""
    pass

def EVT_COMMAND_LEFT_DCLICK(win, id, func):
    """"""
    pass

def EVT_COMMAND_RANGE(win, id1, id2, cmd, func):
    """"""
    pass

def EVT_COMMAND_RIGHT_CLICK(win, id, func):
    """"""
    pass

def EVT_COMMAND_RIGHT_DCLICK(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_BOTTOM(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_LINEDOWN(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_LINEUP(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_PAGEDOWN(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_PAGEUP(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_THUMBRELEASE(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_THUMBTRACK(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_TOP(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_BOTTOM(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_ENDSCROLL(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_LINEDOWN(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_LINEUP(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_PAGEDOWN(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_PAGEUP(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_THUMBRELEASE(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_THUMBTRACK(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_TOP(win, id, func):
    """"""
    pass

def EVT_COMMAND_SET_FOCUS(win, id, func):
    """"""
    pass

def EVT_CONTEXT_MENU(win, func):
    """"""
    pass

def EVT_DISPLAY_CHANGED(win, func):
    """"""
    pass

def EVT_DROP_FILES(win, func):
    """"""
    pass

def EVT_END_PROCESS(eh, id, func):
    """"""
    pass

def EVT_END_SESSION(win, func):
    """"""
    pass

def EVT_ENTER_WINDOW(win, func):
    """"""
    pass

def EVT_ERASE_BACKGROUND(win, func):
    """"""
    pass

def EVT_ICONIZE(win, func):
    """"""
    pass

def EVT_IDLE(win, func):
    """"""
    pass

def EVT_INIT_DIALOG(win, func):
    """"""
    pass

def EVT_JOYSTICK_EVENTS(win, func):
    """"""
    pass

def EVT_JOY_DOWN(win, func):
    """"""
    pass

def EVT_JOY_MOVE(win, func):
    """"""
    pass

def EVT_JOY_UP(win, func):
    """"""
    pass

def EVT_JOY_ZMOVE(win, func):
    """"""
    pass

def EVT_KEY_DOWN(win, func):
    """"""
    pass

def EVT_KEY_UP(win, func):
    """"""
    pass

def EVT_KILL_FOCUS(win, func):
    """"""
    pass

def EVT_LEAVE_WINDOW(win, func):
    """"""
    pass

def EVT_LEFT_DCLICK(win, func):
    """"""
    pass

def EVT_LEFT_DOWN(win, func):
    """"""
    pass

def EVT_LEFT_UP(win, func):
    """"""
    pass

def EVT_LISTBOX(win, id, func):
    """"""
    pass

def EVT_LISTBOX_DCLICK(win, id, func):
    """"""
    pass

def EVT_LIST_BEGIN_DRAG():
    """"""
    pass

def EVT_LIST_BEGIN_LABEL_EDIT():
    """"""
    pass

def EVT_LIST_BEGIN_RDRAG():
    """"""
    pass

def EVT_LIST_CACHE_HINT():
    """"""
    pass

def EVT_LIST_COL_BEGIN_DRAG():
    """"""
    pass

def EVT_LIST_COL_CLICK():
    """"""
    pass

def EVT_LIST_COL_DRAGGING():
    """"""
    pass

def EVT_LIST_COL_END_DRAG():
    """"""
    pass

def EVT_LIST_COL_RIGHT_CLICK():
    """"""
    pass

def EVT_LIST_DELETE_ALL_ITEMS():
    """"""
    pass

def EVT_LIST_DELETE_ITEM():
    """"""
    pass

def EVT_LIST_END_LABEL_EDIT():
    """"""
    pass

def EVT_LIST_GET_INFO():
    """"""
    pass

def EVT_LIST_INSERT_ITEM():
    """"""
    pass

def EVT_LIST_ITEM_ACTIVATED():
    """"""
    pass

def EVT_LIST_ITEM_DESELECTED():
    """"""
    pass

def EVT_LIST_ITEM_FOCUSED():
    """"""
    pass

def EVT_LIST_ITEM_MIDDLE_CLICK():
    """"""
    pass

def EVT_LIST_ITEM_RIGHT_CLICK():
    """"""
    pass

def EVT_LIST_ITEM_SELECTED():
    """"""
    pass

def EVT_LIST_KEY_DOWN():
    """"""
    pass

def EVT_LIST_SET_INFO():
    """"""
    pass

def EVT_MAXIMIZE(win, func):
    """"""
    pass

def EVT_MENU(win, id, func):
    """"""
    pass

def EVT_MENU_CLOSE(win, func):
    """"""
    pass

def EVT_MENU_HIGHLIGHT(win, id, func):
    """"""
    pass

def EVT_MENU_HIGHLIGHT_ALL(win, func):
    """"""
    pass

def EVT_MENU_OPEN(win, func):
    """"""
    pass

def EVT_MENU_RANGE(win, id1, id2, func):
    """"""
    pass

def EVT_MIDDLE_DCLICK(win, func):
    """"""
    pass

def EVT_MIDDLE_DOWN(win, func):
    """"""
    pass

def EVT_MIDDLE_UP(win, func):
    """"""
    pass

def EVT_MOTION(win, func):
    """"""
    pass

def EVT_MOUSEWHEEL(win, func):
    """"""
    pass

def EVT_MOUSE_CAPTURE_CHANGED(win, func):
    """"""
    pass

def EVT_MOUSE_EVENTS(win, func):
    """"""
    pass

def EVT_MOVE(win, func):
    """"""
    pass

def EVT_NAVIGATION_KEY(win, func):
    """"""
    pass

def EVT_NOTEBOOK_PAGE_CHANGED(win, id, func):
    """"""
    pass

def EVT_NOTEBOOK_PAGE_CHANGING(win, id, func):
    """"""
    pass

def EVT_PAINT(win, func):
    """"""
    pass

def EVT_PALETTE_CHANGED(win, func):
    """"""
    pass

def EVT_QUERY_END_SESSION(win, func):
    """"""
    pass

def EVT_QUERY_LAYOUT_INFO():
    """"""
    pass

def EVT_QUERY_NEW_PALETTE(win, func):
    """"""
    pass

def EVT_RADIOBOX(win, id, func):
    """"""
    pass

def EVT_RADIOBUTTON(win, id, func):
    """"""
    pass

def EVT_RIGHT_DCLICK(win, func):
    """"""
    pass

def EVT_RIGHT_DOWN(win, func):
    """"""
    pass

def EVT_RIGHT_UP(win, func):
    """"""
    pass

def EVT_SASH_DRAGGED(win, id, func):
    """"""
    pass

def EVT_SASH_DRAGGED_RANGE(win, id1, id2, func):
    """"""
    pass

def EVT_SCROLL(win, func):
    """"""
    pass

def EVT_SCROLLWIN(win, func):
    """"""
    pass

def EVT_SCROLLWIN_BOTTOM(win, func):
    """"""
    pass

def EVT_SCROLLWIN_LINEDOWN(win, func):
    """"""
    pass

def EVT_SCROLLWIN_LINEUP(win, func):
    """"""
    pass

def EVT_SCROLLWIN_PAGEDOWN(win, func):
    """"""
    pass

def EVT_SCROLLWIN_PAGEUP(win, func):
    """"""
    pass

def EVT_SCROLLWIN_THUMBRELEASE(win, func):
    """"""
    pass

def EVT_SCROLLWIN_THUMBTRACK(win, func):
    """"""
    pass

def EVT_SCROLLWIN_TOP(win, func):
    """"""
    pass

def EVT_SCROLL_BOTTOM(win, func):
    """"""
    pass

def EVT_SCROLL_ENDSCROLL(win, func):
    """"""
    pass

def EVT_SCROLL_LINEDOWN(win, func):
    """"""
    pass

def EVT_SCROLL_LINEUP(win, func):
    """"""
    pass

def EVT_SCROLL_PAGEDOWN(win, func):
    """"""
    pass

def EVT_SCROLL_PAGEUP(win, func):
    """"""
    pass

def EVT_SCROLL_THUMBRELEASE(win, func):
    """"""
    pass

def EVT_SCROLL_THUMBTRACK(win, func):
    """"""
    pass

def EVT_SCROLL_TOP(win, func):
    """"""
    pass

def EVT_SET_CURSOR(win, func):
    """"""
    pass

def EVT_SET_FOCUS(win, func):
    """"""
    pass

def EVT_SHOW(win, func):
    """"""
    pass

def EVT_SIZE():
    """"""
    pass

def EVT_SLIDER(win, id, func):
    """"""
    pass

def EVT_SPIN(win, id, func):
    """"""
    pass

def EVT_SPINCTRL(win, id, func):
    """"""
    pass

def EVT_SPIN_DOWN(win, id, func):
    """"""
    pass

def EVT_SPIN_UP(win, id, func):
    """"""
    pass

def EVT_SPLITTER_DOUBLECLICKED(win, id, func):
    """"""
    pass

def EVT_SPLITTER_SASH_POS_CHANGED(win, id, func):
    """"""
    pass

def EVT_SPLITTER_SASH_POS_CHANGING(win, id, func):
    """"""
    pass

def EVT_SPLITTER_UNSPLIT(win, id, func):
    """"""
    pass

def EVT_SYS_COLOUR_CHANGED(win, func):
    """"""
    pass

def EVT_TASKBAR_LEFT_DCLICK(win, func):
    """"""
    pass

def EVT_TASKBAR_LEFT_DOWN(win, func):
    """"""
    pass

def EVT_TASKBAR_LEFT_UP(win, func):
    """"""
    pass

def EVT_TASKBAR_MOVE(win, func):
    """"""
    pass

def EVT_TASKBAR_RIGHT_DCLICK(win, func):
    """"""
    pass

def EVT_TASKBAR_RIGHT_DOWN(win, func):
    """"""
    pass

def EVT_TASKBAR_RIGHT_UP(win, func):
    """"""
    pass

def EVT_TEXT(win, id, func):
    """"""
    pass

def EVT_TEXT_ENTER(win, id, func):
    """"""
    pass

def EVT_TEXT_MAXLEN(win, id, func):
    """"""
    pass

def EVT_TEXT_URL(win, id, func):
    """"""
    pass

def EVT_TIMER(win, id, func):
    """"""
    pass

def EVT_TOGGLEBUTTON(win, id, func):
    """"""
    pass

def EVT_TOOL(win, id, func):
    """"""
    pass

def EVT_TOOL_ENTER(win, id, func):
    """"""
    pass

def EVT_TOOL_RANGE(win, id, id2, func):
    """"""
    pass

def EVT_TOOL_RCLICKED(win, id, func):
    """"""
    pass

def EVT_TOOL_RCLICKED_RANGE(win, id, id2, func):
    """"""
    pass

def EVT_TREE_BEGIN_DRAG():
    """"""
    pass

def EVT_TREE_BEGIN_LABEL_EDIT():
    """"""
    pass

def EVT_TREE_BEGIN_RDRAG():
    """"""
    pass

def EVT_TREE_DELETE_ITEM():
    """"""
    pass

def EVT_TREE_END_DRAG():
    """"""
    pass

def EVT_TREE_END_LABEL_EDIT():
    """"""
    pass

def EVT_TREE_GET_INFO():
    """"""
    pass

def EVT_TREE_ITEM_ACTIVATED():
    """"""
    pass

def EVT_TREE_ITEM_COLLAPSED():
    """"""
    pass

def EVT_TREE_ITEM_COLLAPSING():
    """"""
    pass

def EVT_TREE_ITEM_EXPANDED():
    """"""
    pass

def EVT_TREE_ITEM_EXPANDING():
    """"""
    pass

def EVT_TREE_ITEM_MIDDLE_CLICK():
    """"""
    pass

def EVT_TREE_ITEM_RIGHT_CLICK():
    """"""
    pass

def EVT_TREE_KEY_DOWN():
    """"""
    pass

def EVT_TREE_SEL_CHANGED():
    """"""
    pass

def EVT_TREE_SEL_CHANGING():
    """"""
    pass

def EVT_TREE_SET_INFO():
    """"""
    pass

def EVT_UPDATE_UI(win, id, func):
    """"""
    pass

def EVT_UPDATE_UI_RANGE(win, id, id2, func):
    """"""
    pass

def EVT_VLBOX(win, id, func):
    """"""
    pass

def EVT_WINDOW_CREATE(win, func):
    """"""
    pass

def EVT_WINDOW_DESTROY(win, func):
    """"""
    pass





"""PyCrustApp is a python shell and namespace browser application."""

# The next two lines, and the other code below that makes use of
# ``__main__`` and ``original``, serve the purpose of cleaning up the
# main namespace to look as much as possible like the regular Python
# shell environment.
import __main__
original = __main__.__dict__.keys()

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: PyCrustApp.py,v 1.9.2.5 2003/03/20 23:14:32 RD Exp $"
__revision__ = "$Revision: 1.9.2.5 $"[11:-2]

from wxPython import wx

try:
    True
except NameError:
    True = 1==1
    False = 1==0


class App(wx.wxApp):
    """PyCrust standalone application."""

    def OnInit(self):
        from wxPython import wx
        wx.wxInitAllImageHandlers()
        locals = __main__.__dict__
        from crust import CrustFrame
        self.frame = CrustFrame(locals=locals)
        self.frame.SetSize((800, 600))
        self.frame.Show()
        self.SetTopWindow(self.frame)
        # Add the application object to the sys module's namespace.
        # This allows a shell user to do:
        # >>> import sys
        # >>> sys.app.whatever
        import sys
        sys.app = self
        return 1

'''
The main() function needs to handle being imported, such as with the
pycrust script that wxPython installs:

    #!/usr/bin/env python

    from wxPython.lib.PyCrust.PyCrustApp import main
    main()
'''

def main():
    import __main__
    md = __main__.__dict__
    keepers = original
    keepers.append('App')
    for key in md.keys():
        if key not in keepers:
            del md[key]
    app = App(0)
    if md.has_key('App') and md['App'] is App:
        del md['App']
    if md.has_key('__main__') and md['__main__'] is __main__:
        del md['__main__']
    app.MainLoop()

if __name__ == '__main__':
    main()



# Name:         undo.py
# Purpose:      XRC editor, undo/redo module
# Author:       Roman Rolinsky <rolinsky@mema.ucl.ac.be>
# Created:      01.12.2002
# RCS-ID:       $Id: undo.py,v 1.1.2.2 2003/02/26 18:37:58 RD Exp $

from globals import *
#from panel import *

# Undo/redo classes
class UndoManager:
    # Undo/redo stacks
    undo = []
    redo = []
    def RegisterUndo(self, undoObj):
        self.undo.append(undoObj)
        for i in self.redo: i.destroy()
        self.redo = []
    def Undo(self):
        undoObj = self.undo.pop()
        undoObj.undo()
        self.redo.append(undoObj)
        g.frame.modified = True
        g.frame.SetStatusText('Undone')
    def Redo(self):
        undoObj = self.redo.pop()
        undoObj.redo()
        self.undo.append(undoObj)
        g.frame.modified = True
        g.frame.SetStatusText('Redone')
    def Clear(self):
        for i in self.undo: i.destroy()
        self.undo = []
        for i in self.redo: i.destroy()
        self.redo = []
    def CanUndo(self):
        return not not self.undo
    def CanRedo(self):
        return not not self.redo

class UndoCutDelete:
    def __init__(self, itemIndex, parent, elem):
        self.itemIndex = itemIndex
        self.parent = parent
        self.elem = elem
    def destroy(self):
        if self.elem: self.elem.unlink()
    def undo(self):
        item = g.tree.InsertNode(g.tree.ItemAtFullIndex(self.itemIndex[:-1]),
                                 self.parent, self.elem,
                                 g.tree.ItemAtFullIndex(self.itemIndex))
        # Scroll to show new item (!!! redundant?)
        g.tree.EnsureVisible(item)
        g.tree.SelectItem(item)
        self.elem = None
        # Update testWin if needed
        if g.testWin and g.tree.IsHighlatable(item):
            if g.conf.autoRefresh:
                g.tree.needUpdate = True
                g.tree.pendingHighLight = item
            else:
                g.tree.pendingHighLight = None
    def redo(self):
        item = g.tree.ItemAtFullIndex(self.itemIndex)
        # Delete testWin?
        if g.testWin:
            # If deleting top-level item, delete testWin
            if item == g.testWin.item:
                g.testWin.Destroy()
                g.testWin = None
            else:
                # Remove highlight, update testWin
                if g.testWin.highLight:
                    g.testWin.highLight.Remove()
                g.tree.needUpdate = True
        self.elem = g.tree.RemoveLeaf(item)
        g.tree.Unselect()
        g.panel.Clear()

class UndoPasteCreate:
    def __init__(self, itemParent, parent, item, selected):
        self.itemParentIndex = g.tree.ItemFullIndex(itemParent)
        self.parent = parent
        self.itemIndex = g.tree.ItemFullIndex(item) # pasted item
        self.selectedIndex = g.tree.ItemFullIndex(selected) # maybe different from item
        self.elem = None
    def destroy(self):
        if self.elem: self.elem.unlink()
    def undo(self):
        self.elem = g.tree.RemoveLeaf(g.tree.ItemAtFullIndex(self.itemIndex))
        # Restore old selection
        selected = g.tree.ItemAtFullIndex(self.selectedIndex)
        g.tree.EnsureVisible(selected)
        g.tree.SelectItem(selected)
        # Delete testWin?
        if g.testWin:
            # If deleting top-level item, delete testWin
            if selected == g.testWin.item:
                g.testWin.Destroy()
                g.testWin = None
            else:
                # Remove highlight, update testWin
                if g.testWin.highLight:
                    g.testWin.highLight.Remove()
                g.tree.needUpdate = True
    def redo(self):
        item = g.tree.InsertNode(g.tree.ItemAtFullIndex(self.itemParentIndex),
                                 self.parent, self.elem,
                                 g.tree.ItemAtFullIndex(self.itemIndex))
        # Scroll to show new item
        g.tree.EnsureVisible(item)
        g.tree.SelectItem(item)
        self.elem = None
        # Update testWin if needed
        if g.testWin and g.tree.IsHighlatable(item):
            if g.conf.autoRefresh:
                g.tree.needUpdate = True
                g.tree.pendingHighLight = item
            else:
                g.tree.pendingHighLight = None

class UndoEdit:
    def __init__(self):
        self.pages = map(ParamPage.GetState, g.panel.pages)
        self.selectedIndex = g.tree.ItemFullIndex(g.tree.GetSelection())
    def destroy(self):
        pass
    # Update test view
    def update(self, selected):
        g.tree.Apply(g.tree.GetPyData(selected), selected)
        # Update view
        if g.testWin:
            if g.testWin.highLight:
                g.testWin.highLight.Remove()
            g.tree.pendingHighLight = selected
        if g.testWin:
            g.tree.needUpdate = True
    def undo(self):
        # Restore selection
        selected = g.tree.ItemAtFullIndex(self.selectedIndex)
        if selected != g.tree.GetSelection():
            g.tree.SelectItem(selected)
        # Save current state for redo
        map(ParamPage.SaveState, g.panel.pages)
        pages = map(ParamPage.GetState, g.panel.pages)
        map(ParamPage.SetState, g.panel.pages, self.pages)
        self.pages = pages
        self.update(selected)
    def redo(self):
        self.undo()
        self.update(g.tree.GetSelection())



# This file was created automatically by SWIG.
import htmlhelpc

from misc import *

from misc2 import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from events import *

from streams import *

from utils import *

from mdi import *

from frames import *

from stattool import *

from controls import *

from controls2 import *

from windows2 import *

from cmndlgs import *

from windows3 import *

from image import *

from printfw import *

from sizers import *

from filesys import *
class wxHtmlBookRecordPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetBookFile(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlBookRecord_GetBookFile,(self,) + _args, _kwargs)
        return val
    def GetTitle(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlBookRecord_GetTitle,(self,) + _args, _kwargs)
        return val
    def GetStart(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlBookRecord_GetStart,(self,) + _args, _kwargs)
        return val
    def GetBasePath(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlBookRecord_GetBasePath,(self,) + _args, _kwargs)
        return val
    def SetContentsRange(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlBookRecord_SetContentsRange,(self,) + _args, _kwargs)
        return val
    def GetContentsStart(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlBookRecord_GetContentsStart,(self,) + _args, _kwargs)
        return val
    def GetContentsEnd(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlBookRecord_GetContentsEnd,(self,) + _args, _kwargs)
        return val
    def SetTitle(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlBookRecord_SetTitle,(self,) + _args, _kwargs)
        return val
    def SetBasePath(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlBookRecord_SetBasePath,(self,) + _args, _kwargs)
        return val
    def SetStart(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlBookRecord_SetStart,(self,) + _args, _kwargs)
        return val
    def GetFullPath(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlBookRecord_GetFullPath,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlBookRecord instance at %s>" % (self.this,)
class wxHtmlBookRecord(wxHtmlBookRecordPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlhelpc.new_wxHtmlBookRecord,_args,_kwargs)
        self.thisown = 1




class wxHtmlContentsItemPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetLevel(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlContentsItem_GetLevel,(self,) + _args, _kwargs)
        return val
    def GetID(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlContentsItem_GetID,(self,) + _args, _kwargs)
        return val
    def GetName(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlContentsItem_GetName,(self,) + _args, _kwargs)
        return val
    def GetPage(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlContentsItem_GetPage,(self,) + _args, _kwargs)
        return val
    def GetBook(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlContentsItem_GetBook,(self,) + _args, _kwargs)
        if val: val = wxHtmlBookRecordPtr(val) 
        return val
    def __repr__(self):
        return "<C wxHtmlContentsItem instance at %s>" % (self.this,)
class wxHtmlContentsItem(wxHtmlContentsItemPtr):
    def __init__(self,this):
        self.this = this




class wxHtmlSearchStatusPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Search(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlSearchStatus_Search,(self,) + _args, _kwargs)
        return val
    def IsActive(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlSearchStatus_IsActive,(self,) + _args, _kwargs)
        return val
    def GetCurIndex(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlSearchStatus_GetCurIndex,(self,) + _args, _kwargs)
        return val
    def GetMaxIndex(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlSearchStatus_GetMaxIndex,(self,) + _args, _kwargs)
        return val
    def GetName(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlSearchStatus_GetName,(self,) + _args, _kwargs)
        return val
    def GetContentsItem(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlSearchStatus_GetContentsItem,(self,) + _args, _kwargs)
        if val: val = wxHtmlContentsItemPtr(val) 
        return val
    def __repr__(self):
        return "<C wxHtmlSearchStatus instance at %s>" % (self.this,)
class wxHtmlSearchStatus(wxHtmlSearchStatusPtr):
    def __init__(self,this):
        self.this = this




class wxHtmlHelpDataPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=htmlhelpc.delete_wxHtmlHelpData):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def SetTempDir(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpData_SetTempDir,(self,) + _args, _kwargs)
        return val
    def AddBook(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpData_AddBook,(self,) + _args, _kwargs)
        return val
    def FindPageByName(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpData_FindPageByName,(self,) + _args, _kwargs)
        return val
    def FindPageById(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpData_FindPageById,(self,) + _args, _kwargs)
        return val
    def GetBookRecArray(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpData_GetBookRecArray,(self,) + _args, _kwargs)
        return val
    def GetContents(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpData_GetContents,(self,) + _args, _kwargs)
        if val: val = wxHtmlContentsItemPtr(val) 
        return val
    def GetContentsCnt(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpData_GetContentsCnt,(self,) + _args, _kwargs)
        return val
    def GetIndex(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpData_GetIndex,(self,) + _args, _kwargs)
        if val: val = wxHtmlContentsItemPtr(val) 
        return val
    def GetIndexCnt(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpData_GetIndexCnt,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlHelpData instance at %s>" % (self.this,)
class wxHtmlHelpData(wxHtmlHelpDataPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlhelpc.new_wxHtmlHelpData,_args,_kwargs)
        self.thisown = 1




class wxHtmlHelpFramePtr(wxFramePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetData(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpFrame_GetData,(self,) + _args, _kwargs)
        if val: val = wxHtmlHelpDataPtr(val) 
        return val
    def SetTitleFormat(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpFrame_SetTitleFormat,(self,) + _args, _kwargs)
        return val
    def Display(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpFrame_Display,(self,) + _args, _kwargs)
        return val
    def DisplayID(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpFrame_DisplayID,(self,) + _args, _kwargs)
        return val
    def DisplayContents(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpFrame_DisplayContents,(self,) + _args, _kwargs)
        return val
    def DisplayIndex(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpFrame_DisplayIndex,(self,) + _args, _kwargs)
        return val
    def KeywordSearch(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpFrame_KeywordSearch,(self,) + _args, _kwargs)
        return val
    def UseConfig(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpFrame_UseConfig,(self,) + _args, _kwargs)
        return val
    def ReadCustomization(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpFrame_ReadCustomization,(self,) + _args, _kwargs)
        return val
    def WriteCustomization(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpFrame_WriteCustomization,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxHtmlHelpFrame instance at %s>" % (self.this,)
class wxHtmlHelpFrame(wxHtmlHelpFramePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlhelpc.new_wxHtmlHelpFrame,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxHtmlHelpControllerPtr(wxEvtHandlerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=htmlhelpc.delete_wxHtmlHelpController):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def SetTitleFormat(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpController_SetTitleFormat,(self,) + _args, _kwargs)
        return val
    def SetTempDir(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpController_SetTempDir,(self,) + _args, _kwargs)
        return val
    def AddBook(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpController_AddBook,(self,) + _args, _kwargs)
        return val
    def Display(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpController_Display,(self,) + _args, _kwargs)
        return val
    def DisplayID(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpController_DisplayID,(self,) + _args, _kwargs)
        return val
    def DisplayContents(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpController_DisplayContents,(self,) + _args, _kwargs)
        return val
    def DisplayIndex(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpController_DisplayIndex,(self,) + _args, _kwargs)
        return val
    def KeywordSearch(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpController_KeywordSearch,(self,) + _args, _kwargs)
        return val
    def UseConfig(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpController_UseConfig,(self,) + _args, _kwargs)
        return val
    def ReadCustomization(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpController_ReadCustomization,(self,) + _args, _kwargs)
        return val
    def WriteCustomization(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpController_WriteCustomization,(self,) + _args, _kwargs)
        return val
    def GetFrame(self, *_args, **_kwargs):
        val = apply(htmlhelpc.wxHtmlHelpController_GetFrame,(self,) + _args, _kwargs)
        if val: val = wxHtmlHelpFramePtr(val) 
        return val
    def __repr__(self):
        return "<C wxHtmlHelpController instance at %s>" % (self.this,)
class wxHtmlHelpController(wxHtmlHelpControllerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(htmlhelpc.new_wxHtmlHelpController,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)






#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------

wxHF_TOOLBAR = htmlhelpc.wxHF_TOOLBAR
wxHF_FLATTOOLBAR = htmlhelpc.wxHF_FLATTOOLBAR
wxHF_CONTENTS = htmlhelpc.wxHF_CONTENTS
wxHF_INDEX = htmlhelpc.wxHF_INDEX
wxHF_SEARCH = htmlhelpc.wxHF_SEARCH
wxHF_BOOKMARKS = htmlhelpc.wxHF_BOOKMARKS
wxHF_OPENFILES = htmlhelpc.wxHF_OPENFILES
wxHF_PRINT = htmlhelpc.wxHF_PRINT
wxHF_DEFAULTSTYLE = htmlhelpc.wxHF_DEFAULTSTYLE
